<?php
/**
* Plugin Name: Crew Manager
* File get-eventcrew-crontask.php
* File Version 0.2Beta
* Author: Bill Kneller
* Author URI: http://crew-mgr.com
*
* 4/22/2018 made sure "Stay Ashore" gets email by removing
* AND cma.position_id !=$stay_ashore from crew query
* This is called by cron to get the list of crew members & ai1ec posts.
* The output will be used by the "Email posts to subscribers" plugin
* 1.  Clears the previously stored post IDs and users to start fresh
* 2.  Checks what ai1ec events are scheduled >= 36 to = 37 hours later
* 3.  Saves the post IDs for these events 
* 4.  Gets the users (crew members) associated with the found post IDs
* 5.  Writes the users to the table wp_elp_emaillist (no duplicates)
*     in group EventCrew as Confirmed
* 6.  Sets event to draft, then Publish to trigger elp Send Post
**/
$debug="Yes";  // Set to "Yes" to turn on debug echo displays 
error_reporting(E_ALL & ~E_NOTICE & ~E_WARNING); // turn off error and warning notices
/** Loads the WordPress Environment  */
require("../../../../wp-load.php"); //file path is from plugin/crew-manager/ directory

$execute=event_crew_cron($debug);

//function event_crew_cron($atts, $event_crew = null){
function event_crew_cron($debug){
global $wpdb;
global $crew_manager_options;
$stay_ashore = get_position_id_number('Stay Ashore');
$hours_lower = $crew_manager_options['lead_time']; // start looking 36 hours in advanceor as set in admin panel
$hours_upper = $hours_lower + 1;  // finish looking lower + 1 hour in advance
$elp_send_message_cron_trigger = "";
global $crew_manager_options;
if ($crew_manager_options['elp_cron_trigger']==1) { ; // gets elp cron trigger from admin panel setup 1 is Crew Manager, 2 is ELP CRON from cPanel
	$elp_cron_url = get_option('elp_c_cronurl', 'nocronurl');
	if($elp_cron_url == "nocronurl") {
		$guid = elp_cls_common::elp_generate_guid(60);
		$home_url = home_url('/');
		$cronurl = $home_url . "?elp=cron&guid=". $guid;
		$elp_cron_url = get_option('elp_c_cronurl');
if ($debug=="Yes") echo "cronurl: " . $elp_cron_url , "<br>";
	}
$elp_send_message_cron_trigger = $elp_cron_url; // sets ELP URL for CRON
}



if ($debug=="Yes") echo "<b>Debug Displays enabled with $"."debug set to \"Yes\"</b><br>";
$theme_path = get_stylesheet_directory_uri();
$cur_yr = date('Y'); // gets curent year for query
$cur_datetime = strtotime(date("Y-m-d H:i:s")); // gets curent datetime for query
$future_lower_limit = mktime(date('H')+$hours_lower,date('i'),date('s'),date('n'),date('j'),date('Y'));
$future_upper_limit = mktime(date('H')+$hours_upper,date('i'),date('s'),date('n'),date('j'),date('Y'));

if ($debug == "Yes") {
   echo "&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;Current Time UTC: ".$cur_datetime."  ".date('Y-m-d H:i:s',$cur_datetime)."<br>"; //debug
   echo "&nbsp;>= Lower Limit UTC: ".$future_lower_limit."  ".date('Y-m-d H:i:s',$future_lower_limit)."&nbsp;&nbsp;(".$hours_lower." hours)<br>"; //debug
   echo "&nbsp;&nbsp;&nbsp;&nbsp;< Upper Limit UTC: ".$future_upper_limit."  ".date('Y-m-d H:i:s',$future_upper_limit)."&nbsp;&nbsp;(".$hours_upper." hours)<br>"; //debug
echo "CRON Trigger URL: " . $elp_send_message_cron_trigger . "<br>";
}
// first get the wp global and add prefix so existing data stored may be cleared
    $table_ai1ec_events  = $wpdb->prefix."ai1ec_events";
    $table_ai1ec_instances  = $wpdb->prefix."ai1ec_event_instances";
    $table_crewmgr_assigned  = $wpdb->prefix."crewmgr_assigned";
    $table_crewmgr_position  = $wpdb->prefix."crewmgr_position";
    $table_users  = $wpdb->prefix."users";
    $table_posts  = $wpdb->prefix."posts";
    $table_usermeta  = $wpdb->prefix."usermeta";
    $table_elp_emaillist  = $wpdb->prefix."elp_emaillist";
    $current_date = current_time( 'mysql' ); // uses Wordpress call

$skipper=$crew_manager_options['skipper_name']; 
if ($debug=="Yes") echo "<b>Table</b> should be <b>wp_elp_emaillist</b>: ".$table_elp_emaillist."<br>";  // debug to make sure correct table is called
// delete any users in EventCrew group from the table
    $wpdb->query("DELETE  FROM $table_elp_emaillist WHERE elp_email_group = 'EventCrew' AND elp_email_name != '$skipper'");

// ai1ec post query by time here
$eventquery = $wpdb->get_results("SELECT p.ID 'PostID', e.start 'DateTime' FROM $table_ai1ec_events e, $table_ai1ec_instances i, $table_posts p 
WHERE e.post_id = p.ID
AND e.post_id = i.post_id
AND p.post_status = 'publish'
AND FROM_UNIXTIME(e.start, '%Y') = $cur_yr
AND e.start >= $future_lower_limit 
AND e.start < $future_upper_limit 
GROUP BY p.ID
ORDER BY e.start
", ARRAY_A);

// var_dump($eventquery); // debug
// echo "before foreach(eventquery as erow)<br>"; debug
// echo "Post ID: ".$postid."  Lower Limit: ".$future_lower_limit."  Upper Limit: ".$future_upper_limit."<br>"; //debug
foreach($eventquery as $erow)
{
$postid = $erow[PostID];
// var_dump($eventquery);
// echo "Post ID: ".$postid."  DateTime: ".date('Y-m-d H:i:s',$erow[DateTime])."  Lower Limit: ".date('Y-m-d H:i:s',$future_lower_limit)."  Upper Limit: ".date('Y-m-d H:i:s',$future_upper_limit)."<br>"; //debug

// Get crew members for selected post
// exclude not available, and available if position designated as Stay Ashore
$crewquery = $wpdb->get_results("SELECT u.ID 'ID', cmp.position_id 'PosID', cma.available 'Available'  FROM $table_ai1ec_events e, $table_crewmgr_assigned cma, $table_crewmgr_position cmp, $table_users u  
WHERE e.post_id = $postid AND cma.ai1ec_post_id = $postid
AND u.ID = cma.user_ID
AND cma.position_id = cmp.position_id
AND cma.available < 3
ORDER BY cma.available, u.display_name
", ARRAY_A);

foreach($crewquery as $row)
{
// var_dump($row); // debug

$user_id = $row['ID'];
$user_info = $user_id ? new WP_User( $user_id ) : wp_get_current_user();
$user_name = $user_info->first_name." ".$user_info->last_name;
$user_email = $user_info->user_email;

// display each $row from query here.
//    echo "<p>".$user_name . " ".$user_email." Confirmed ".$current_date." 0 ". " EventCrew "."<p><br>";

$record_check = $wpdb->get_var("SELECT COUNT(*) FROM $table_elp_emaillist
WHERE elp_email_mail = '$user_email'
AND elp_email_group = 'EventCrew';"); //record is NULL if not in database so insert
    if ($record_check == 0){
// record not found so insert new record
if ($debug=="Yes") echo "Inserted -> " .$user_name . "  Email: ".$user_email." Created: ".$current_date." Post ID: ".$postid."<br>"; //debug
 //debug1 start comment out query
    $wpdb->insert($table_elp_emaillist, array(
        'elp_email_name' => $user_name,
        'elp_email_mail' => $user_email,
        'elp_email_status' => 'Confirmed', 
        'elp_email_created' => $current_date,
        'elp_email_viewcount' => 0,
        'elp_email_group' => 'EventCrew'
    ));
 //debug1 end
    } ELSE {
// record found so ignore it
if ($debug=="Yes") echo "-->Ignored -> " .$user_name . "  Email: ".$user_email." Created: ".$current_date." Post ID: ".$postid."<br>"; //debug
    }
// end foreach($crewquery as $row)
} 
// end foreach($crewquery as $row)
//****** //debug turn off post status change
// now set to draft and republish the event to trigger email
// Update post setup array
  $my_post = array(
      'ID'           => $postid,
      'post_status'   => 'draft',
  );

// Update the post into the database
  wp_update_post( $my_post ); // sets post to draft
if ($debug=="Yes") echo "Post ID Unpublished: ".$postid."<br>"; // debug
wp_publish_post( $postid ); // this publishes the event to trigger email notification
if ($debug=="Yes") echo "Post ID Published: ".$postid."<br>"; // debug
//*****/ // end debug turn off post status change
if ($debug=="Yes") echo "Post ID processed: ".$postid."<br>"; // debug

// end foreach($eventquery as $erow)
} 
// end foreach($eventquery as $erow)
if ($elp_send_message_cron_trigger) {
$ch = curl_init(); // setup to trigger elp send newsletter
//set the url, number of POST vars, POST data
curl_setopt($ch, CURLOPT_URL, $elp_send_message_cron_trigger);
//execute post
$result = curl_exec($ch);   // direct call to cron for debug
//close connection
curl_close($ch);  // close direct call to cron for debug
if ($debug=="Yes") echo "$"."elp_send_message_cron_trigger was activated<br>";
} else {
if ($debug=="Yes"  && $postid)echo "Event in que waiting for cron<br>";
} // no $elp_send_message_cron_trigger so finish

} // end function
?>