<?php
/*
* Plugin Name: Crew Manager
* File functions.php
* File Version 0.3Beta
* Author: Bill Kneller
* Author URI: http://crew-mgr.com

* Name: Functions Used by Other files
* for Crew Manager plugin - using shortcodes.
* This file also has houskeeping functions like
* adding login/logout to menu, redirect to home page
* on login/logout, add extra fields to user in WP Admin.
*
* 4/27/2018 changed login to allow redirect from [crew] also
* 4/22/2018 revised position dropdown to hide admin & Graphene hide
**/

/** removes admin bar search when logged in **/
function remove_admin_menu_bar_items ($wp_toolbar) {
//    $wp_toolbar->remove_node( 'my-sites' );
//    $wp_toolbar->remove_node( 'wp-logo' );
//    $wp_toolbar->remove_node( 'new-content' );
//    $wp_toolbar->remove_node( 'view' );
    $wp_toolbar->remove_node( 'search' );  // remove the search element
    return $wp_toolbar;
}
add_filter( 'admin_bar_menu', 'remove_admin_menu_bar_items' );


/** function add_login_logout_link ******** 
* this adds a login / logout button to the menu 
**/
error_reporting(E_ALL & ~E_NOTICE); // turn off error notices
add_filter('wp_nav_menu_items', 'add_login_logout_link', 10, 2);
function add_login_logout_link($items, $args) {
/**
replaced with below so login link with redirect could be added to [crew]
        ob_start();
        wp_loginout('index.php');
        $loginoutlink = ob_get_contents();
        ob_end_clean();
        $items .= '<li>'. $loginoutlink .'</li>';
**/

      if (is_user_logged_in()) {
         $items .= '<li class="right"><a href="'. wp_logout_url() .'">'. __("Log Out") .'</a></li>';
      } else {
         $items .= '<li class="right"><a href="'. wp_login_url(home_url()) .'">'. __("Log In") .'</a></li>';
      }

    return $items;
}
// /** end function add_login_logout_link ******** 

/** Commented out with different approch that in cluded redirect for login button in [crew]
/** function my_login_redirect ******** 
* this redirects people to home page after logging in, administrator is 
* redirected to the control panel automatically

function my_login_redirect( $url, $request, $user ){
if( $user && is_object( $user ) && is_a( $user, 'WP_User' ) ) {
if( $user->has_cap( 'administrator') or $user->has_cap( 'author')) {
$url = admin_url();
} else {
$url = home_url();
}
}
return $url;
}

add_filter('login_redirect', 'my_login_redirect', 10, 3 );
// end of my_login_redirect function
// end commenting previous method of login buton and redirect
**/

/** function  logout redirect ******** 
* this redirects people to home page after logging out
**/
add_action('wp_logout','auto_redirect_after_logout');
function auto_redirect_after_logout(){
wp_redirect( home_url() );
exit();
}
// end of logout redirect function


/** adds function my_show_extra_profile_fields( $user )
*   for custom fields added to the user profile and stored in meta 
* https://wordpress.stackexchange.com/questions/214719/how-do-i-add-a-field-on-the-users-profile-for-example-country-age-etc
**/
add_action( 'show_user_profile', 'my_show_extra_profile_fields' );
add_action( 'edit_user_profile', 'my_show_extra_profile_fields' );

function my_show_extra_profile_fields( $user ) { ?>
	<h3>Extra profile information</h3>
	<table class="form-table">
		<tr>
			<th><label for="mobile">Mobile Phone</label></th>
			<td>
				<input type="text" name="mobile" id="mobile" value="<?php echo esc_attr( get_the_author_meta( 'mobile', $user->ID ) ); ?>" class="regular-text" /><br />
				<span class="description">Please enter your Mobile Phone number.</span>
			</td>
		</tr>
	</table>
<?php }

/** End of function my_show_extra_profile_fields  **/

/** This function my_save_extra_profile_fields( $user )
*   saves the custom fields to the user profile as meta 
**/

add_action( 'personal_options_update', 'my_save_extra_profile_fields' );
add_action( 'edit_user_profile_update', 'my_save_extra_profile_fields' );
add_action( "user_new_form", 'my_show_extra_profile_fields' );

function my_save_extra_profile_fields( $user_id ) {

	if ( !current_user_can( 'edit_user', $user_id ) )
		return false;

	update_usermeta( $user_id, 'mobile', $_POST['mobile'] );
}
/** End of function my_save_extra_profile_fields  **/
add_action('user_register', 'my_save_extra_profile_fields');
add_action('profile_update', 'my_save_extra_profile_fields');



/**
 * Function to populate dropdown box with registered userss 
 *
 * Output is an array variable so that the user data may be displayed
**/
function get_registered_users_dropdown($user_ID)
{
    $dropdown = "<select name='crew' size='1' id='crew'>";
    $dropdown .= "<option value='0'>-- Select Crew --</option>";
global $crew_manager_options;
$wp_admin_hide = "";
if ($crew_manager_options['wp_admin_hide']==1)$wp_admin_hide = 1;    // force initial settings (hide wp admin from roster)
global $wpdb;
 // Adjust the query arguments here if need be.
	$user_args = [
		'orderby' => 'last_name',
		'order' => 'ASC',
	];
	$user_query = new WP_User_Query( $user_args );
	$wp_users = $user_query->get_results();

	foreach( $wp_users as $wp_user ){
			$user_info = get_userdata( $wp_user->ID );
			$user_meta = get_user_meta( $wp_user->ID );
			$graphene_author_hide_email = $user_meta['graphene_author_hide_email'][0];
			$crew_mgr_admin_hide = "";
			$admin_rights = user_can( $user_info->ID, 'activate_plugins' );

			IF ($admin_rights && (int)$wp_admin_hide) $crew_mgr_admin_hide = 1;
			IF ( !$crew_mgr_admin_hide && !$graphene_author_hide_email ){
		    $dropdown .= "<option value=\"". $user_info->ID . "\"";
		    if ($user_ID==$user_info->ID) $dropdown .= " selected ";
		    $dropdown .= ">";
		    $user_firstname = $user_info->first_name;
		    $user_lastname = $user_info->last_name;
		    $dropdown .= $user_info->display_name." -> ".$user_firstname." ".$user_lastname."</option>";
          } ELSE
          { // skip if admin = 1
          }

	} // end foreach
   $dropdown .= "</select>";
return $dropdown;
}
//End function get_registered_users_dropdown / 


/**
 * Function availability_insert_or_update for database table crewmgr_assigned
 * on submission from crew availability page
**/
function availability_insert_or_update($ai1ec_post_id, $user_ID, $available, $position_id, $assigned_value)
{

//        echo "<p>Dump a Record: " . $record_check . "  Post: ". $ai1ec_post_id. "  User: ". $user_ID." Available: ". $available." Position ID: ".$position_id." Assigned: ". $assigned_value."</p>"; //debug
// *bypass* first see if record should be bypassed if no availability
if($available != 0){
// Get the data from the ai1ec_events table in the Wordpress database.
global $wpdb;
    $table_crewmgr_assigned  = $wpdb->prefix."crewmgr_assigned";
$record_check = $wpdb->get_var("SELECT COUNT(id) FROM $table_crewmgr_assigned
WHERE ai1ec_post_id = $ai1ec_post_id
AND user_ID = $user_ID;"); //record is NULL if not in database so insert
    if ($record_check == 0){
// record not found so insert new record
    if ($position_id == 0)$position_id=get_position_id_number("Not Assigned");// force Not Assigned if no selection
//        echo "<p>Insert a Record: " . $record_check . "  Post: ". $ai1ec_post_id. "  User: ". $user_ID." Available: ". $available." Position ID: ".$position_id." Assignment: ". $assigned_value."</p>"; //debug
 //debug1 start comment out query
    $wpdb->insert($table_crewmgr_assigned, array(
        'ai1ec_post_id' => $ai1ec_post_id,
        'user_ID' => $user_ID,
        'available' => $available, 
        'position_id' => $position_id,
        'assignment' => $assigned_value
    ));
 //debug1 end
    } ELSE {
// record found so update record
//        echo "<p>Update a Record: " . $record_check . "  Post: ". $ai1ec_post_id. "  User: ". $user_ID." Available: ". $available." Position ID: ".$position_id." Assignment: ". $assigned_value."</p>"; //debug
 //debug2 start comment out query
        $wpdb->query("UPDATE $table_crewmgr_assigned SET available='$available', position_id='$position_id', assignment= '$assigned_value' WHERE ai1ec_post_id = '$ai1ec_post_id' AND user_ID = '$user_ID'");
  //debug2 end
    }
// echo "<p>Record: " . $record_check . "  Post: ". $ai1ec_post_id. "  User: ". $user_ID."</p>";
}  //*bypass* endif 
}
//End function availability_insert_or_update / 

/**
 * Function load_assignment_text_box to create text box and display previously saved
 * text, if there was any
 * array Key is $avail_index if status already set, otherwise $ai1ec_post_id 
**/
function load_assignment_text($assignment_in, $avail_index, $user_ID, $ai1ec_post_id)
{
// Get the data from the ai1ec_events table in the Wordpress database.
global $wpdb;
    $table_ai1ec_events  = $wpdb->prefix."ai1ec_events";
    $table_crewmgr_assigned  = $wpdb->prefix."crewmgr_assigned";

$query = $wpdb->get_results("SELECT cma.assignment AS  'Assigned', cma.id 'AvailID'  FROM $table_ai1ec_events e, $table_crewmgr_assigned cma
WHERE e.post_id = $ai1ec_post_id AND cma.ai1ec_post_id = $ai1ec_post_id
AND cma.user_ID = $user_ID
", ARRAY_A);
foreach($query as $row)
{
$avail_index=$ai1ec_post_id;
$assignment=$row['Assigned'];
}
$avail_index=$ai1ec_post_id;
    $text = $assignment;
return $text;
}
//End function load_assignment_text / 

/**
 * Function load_assignment_text_box to create text box and display previously saved
 * text, if there was any
 * array Key is $avail_index if status already set, otherwise $ai1ec_post_id 
**/
function load_assignment_text_box($assignment_in, $avail_index, $user_ID, $ai1ec_post_id)
{
// Get the data from the ai1ec_events table in the Wordpress database.
global $wpdb;
    $table_ai1ec_events  = $wpdb->prefix."ai1ec_events";
    $table_crewmgr_assigned  = $wpdb->prefix."crewmgr_assigned";

$query = $wpdb->get_results("SELECT cma.assignment AS  'Assigned', cma.id 'AvailID'  FROM $table_ai1ec_events e, $table_crewmgr_assigned cma
WHERE e.post_id = $ai1ec_post_id AND cma.ai1ec_post_id = $ai1ec_post_id
AND cma.user_ID = $user_ID
", ARRAY_A);
foreach($query as $row)
{
$avail_index=$ai1ec_post_id;
$assignment="";
if (isset($row['Assigned'])) $assignment=$row['Assigned'];
}
$avail_index=$ai1ec_post_id;

//    $textbox = "<input type='textarea' name='assigned[".$avail_index."]' id='assigned[".$avail_index."]'  size='30' maxlength='42' value='$assignment' />";

    $textbox = "<input type='textarea' name='assigned[".$ai1ec_post_id."-".$user_ID."]' id='assigned[".$ai1ec_post_id."-".$user_ID."]'  size='30' maxlength='42' value='$assignment' />";

return $textbox;
}
//End function load_assignment_text_box / 

/**
 * Function load_available_dropdown to populate dropdown box with availability
 * 0 or null = No Input
 * 1 = Yes
 * 2 = Maybe
 * 3 = No
 * array Key is $avail_index if status already set, otherwise $ai1ec_post_id 
**/
function load_available_dropdown($available, $avail_index, $user_ID, $ai1ec_post_id)
{
// Get the data from the ai1ec_events table in the Wordpress database.
global $wpdb;
    $table_ai1ec_events  = $wpdb->prefix."ai1ec_events";
    $table_crewmgr_assigned  = $wpdb->prefix."crewmgr_assigned";

$query = $wpdb->get_results("SELECT cma.available AS  'Available', cma.id 'AvailID'  FROM $table_ai1ec_events e, $table_crewmgr_assigned cma
WHERE e.post_id = $ai1ec_post_id AND cma.ai1ec_post_id = $ai1ec_post_id
AND cma.user_ID = $user_ID
", ARRAY_A);
foreach($query as $row)
{
$avail_index=$ai1ec_post_id;
$available=$row['Available'];
}
$avail_index=$ai1ec_post_id;

    $dropdown = "<select name='available[".$ai1ec_post_id."-".$user_ID."]' size='1' id='available[".$ai1ec_post_id."-".$user_ID."]'>";
//    $dropdown = "<select name='available[".$avail_index."]' size='1' id='available[".$avail_index."]'>";

    $dropdown .= "<option value=0>-- Select Availability --</option>";
    $dropdown .= "<option ";
    if ($available==1 ) $dropdown .= "selected ";
    $dropdown .= "value=1>Yes</option>";
    $dropdown .= "<option ";
    if ($available==2 ) $dropdown .= "selected ";
    $dropdown .= "value=2>Maybe</option>";
    $dropdown .= "<option ";
    if ($available==3 ) $dropdown .= "selected ";
    $dropdown .= "value=3>No</option>";
    $dropdown .= "</select>";
return $dropdown;
}
//End function load_available_dropdown / 

/**
 * Function load_year_dropdown to populate dropdown box 
 * Looks at ai1ec events for oldest entry and sets that year
 * as earliest to show in the year dropdown - defaults to
 * current year
**/
function load_year_dropdown($query_yr)
{
global $wpdb;
    $table_ai1ec_events  = $wpdb->prefix."ai1ec_events";

$timestamp = $wpdb->get_var("SELECT min(start) FROM $table_ai1ec_events"); // gets oldest event timestamp
$oldest_year = date('Y', $timestamp); // extracts the year
$cur_yr = date('Y'); // gets curent year for query
if (!$query_yr) $query_yr = $cur_yr;
    $dropdown = "<select name='query_yr' size='1' id='query_yr'>";
$counter = $cur_yr;	
//echo "query_yr: ".$query_yr. "  counter: ".$counter."<br>"; //debug
while ($oldest_year <= $counter) { 
    $dropdown .= "<option ";
    if ($query_yr==$counter) $dropdown .= "selected ";
    $dropdown .= "value=$counter>$counter</option>";
$counter--;
} // end while counter
    $dropdown .= "</select>";
return $dropdown;
}
//End function load_year_dropdown / 

/**
 * Function provides initial dropdown value to display 
 * 0 or null = No Input
 * 1 = Yes
 * 2 = Maybe
 * 3 = No
 * array Key is $avail_index if status already set, otherwise $ai1ec_post_id 
**/
function initial_dropdown_value($available, $avail_index, $user_ID, $ai1ec_post_id)
{
// Get the data from the ai1ec_events table in the Wordpress database.
global $wpdb;
    $table_ai1ec_events  = $wpdb->prefix."ai1ec_events";
    $table_crewmgr_assigned  = $wpdb->prefix."crewmgr_assigned";

$query = $wpdb->get_results("SELECT cma.available 'Available', cma.id 'AvailID'  FROM $table_ai1ec_events e, $table_crewmgr_assigned cma
WHERE e.post_id = $ai1ec_post_id AND cma.ai1ec_post_id = $ai1ec_post_id
AND cma.user_ID = $user_ID
", ARRAY_A);
foreach($query as $row)
{
    if ($row['AvailID']>>0){$avail_index=$row['AvailID'];} 
    ELSE {$avail_index=$ai1ec_post_id;}
    if ($row['Available']>>0){$available=$row['Available'];} 
    ELSE {$avail_index=$ai1ec_post_id;}
}
    $dropdown = $available;
return $dropdown;
}
//End function initial_dropdown_value / 

/**
 * Function gets available numeric value to display 
 * 0 or null = No Input
 * 1 = Yes
 * 2 = Maybe
 * 3 = No
 * array Key is $avail_index if status already set, otherwise $ai1ec_post_id 
**/
function get_available_value($user_ID, $ai1ec_post_id)
{
// Get the data from the ai1ec_events table in the Wordpress database.
global $wpdb;
    $table_ai1ec_events  = $wpdb->prefix."ai1ec_events";
    $table_crewmgr_assigned  = $wpdb->prefix."crewmgr_assigned";

$query = $wpdb->get_results("SELECT cma.available 'Available', cma.id 'AvailID'  FROM $table_ai1ec_events e, $table_crewmgr_assigned cma
WHERE e.post_id = $ai1ec_post_id AND cma.ai1ec_post_id = $ai1ec_post_id
AND cma.user_ID = $user_ID
", ARRAY_A);
foreach($query as $row)
{
    if ($row['Available']>>0){$available=$row['Available'];} 
    ELSE {$avail_index=$ai1ec_post_id; }
}
$avail_val = "";
if (!empty($available[0])) $avail_val = $available[0];
return $avail_val;

}
//End function get_available_value / 

/**
 * Function get_available_text provides available lookup as text to display 
 * 0 or null = No Input
 * 1 = Yes
 * 2 = Maybe
 * 3 = No
 * input is $avail_index 
**/
function get_available_text($avail_index)
{
$avail_text = "No Input";
if ($avail_index == 1) $avail_text = "Yes";
if ($avail_index == 2) $avail_text = "Maybe";
if ($avail_index == 3) $avail_text = "No";
return $avail_text;
}
//End function get_available_text / 

/**
 * Function get_event_start_location to display in crew box
 * for reminder emails
 * Output is html formatted text using $ai1ec_post_id as key for lookup
**/
function get_event_start_location($ai1ec_post_id)
{
// Get the data from the ai1ec_events table in the Wordpress database.
global $wpdb;
    $table_ai1ec_events  = $wpdb->prefix."ai1ec_events";

$query = $wpdb->get_results("SELECT e.start 'Start', e.venue 'Location'  FROM $table_ai1ec_events e
WHERE e.post_id = $ai1ec_post_id
", ARRAY_A);
foreach($query as $row)
{
global $crew_manager_options;
$tz = $crew_manager_options['time_zone'];
date_default_timezone_set($tz); //Corrects for local
     $event_date=date("D F jS ", $row['Start']);
     $event_time=date("g:iA", $row['Start']); 

$text = "<h4>Be at ". $row['Location'] . " - " . $event_date ." @ ". $event_time ."</h4>";
} // end foreach
return $text;
}
//End function get_event_start_location / 

function get_event_start_date($ai1ec_post_id)
{
// Get the data from the ai1ec_events table in the Wordpress database.
global $wpdb;
    $table_ai1ec_events  = $wpdb->prefix."ai1ec_events";

$query = $wpdb->get_results("SELECT e.start 'Start'FROM $table_ai1ec_events e
WHERE e.post_id = $ai1ec_post_id
", ARRAY_A);
foreach($query as $row)
{
global $crew_manager_options; // allows global [time_offset] and 
$tz = $crew_manager_options['time_zone'];
date_default_timezone_set($tz); //Corrects for local
     $event_date=date("D F jS ", $row['Start']);
     $event_time=date("g:iA", $row['Start']); 
//     $event_time=date("g:iA", ($row['Start'] - 60 * 60 * $crew_manager_options['time_offset'])); //old method - replaced by $tz adjusts UTC to Local
$text = $event_date ." @ ". $event_time ;
} // end foreach
return $text;
}
//End function get_event_start_date / 

function get_event_start_date_no_correction($ai1ec_post_id)
{
// Get the data from the ai1ec_events table in the Wordpress database.
global $wpdb;
    $table_ai1ec_events  = $wpdb->prefix."ai1ec_events";
$query = $wpdb->get_results("SELECT e.start 'Start'FROM $table_ai1ec_events e
WHERE e.post_id = $ai1ec_post_id
", ARRAY_A);
foreach($query as $row)
{
     $event_date=date("D F jS ", $row['Start']);
     $event_time=date("g:iA", ($row['Start'])); //don't adjust UTC to Local
$text = $event_date ." @ ". $event_time ;
} // end foreach
return $text;
}
//End function get_event_start_date_no_correction / 


/**
 * Function to get assigned position for crew availability matrix 
 * Pulls stored value from database and returns "Not Assigned" if not found
**/
function get_position($user_ID, $ai1ec_post_id)
{
global $wpdb;
    $table_crewmgr_assigned  = $wpdb->prefix."crewmgr_assigned";
    $table_crewmgr_position  = $wpdb->prefix."crewmgr_position";

$position = $wpdb->get_row("SELECT cmp.position as 'Position' FROM $table_crewmgr_position cmp, $table_crewmgr_assigned cma 
WHERE cma.ai1ec_post_id = $ai1ec_post_id
AND cma.user_ID  = $user_ID
AND cma.position_id = cmp.position_id
");
if ($wpdb->last_error) $pos = "Not Assigned";
$pos = $position->Position;
if (!$pos) $pos = "Not Assigned";
return $pos;
}
//End function get_position  


/**
 * Function to get position_id knowing user and post ID
 * Pulls stored value from database 
**/
function get_position_id($user_ID, $ai1ec_post_id)
{
global $wpdb;
    $table_crewmgr_assigned  = $wpdb->prefix."crewmgr_assigned";

$position_id = $wpdb->get_row("SELECT position_id as 'PosID' FROM $table_crewmgr_assigned 
WHERE user_ID = $user_ID AND ai1ec_post_id = $ai1ec_post_id
");
$pos_id = "";
if ($position_id) $pos_id = $position_id->PosID; 
// echo "user_ID: ".$user_ID."  ai1ec_post_id: ".$ai1ec_post_id."  pos_id: ".$pos_id."<br>"; // debug
return $pos_id;
}
//End function get_position_id  

/**
 * Function to get_assigned_text knowing user and post ID
 * Pulls stored value from database 
**/
function get_assigned_text($user_ID, $ai1ec_post_id)
{
global $wpdb;
    $table_crewmgr_assigned  = $wpdb->prefix."crewmgr_assigned";

$position_id = $wpdb->get_row("SELECT assignment as 'Assigned' FROM $table_crewmgr_assigned 
WHERE user_ID = $user_ID AND ai1ec_post_id = $ai1ec_post_id
");
$assigned_text = "";
if ($position_id) $assigned_text = $position_id->Assigned;
// echo "user_ID: ".$user_ID."  ai1ec_post_id: ".$ai1ec_post_id."  assigned_text: ".$assigned_text."<br>"; // debug
return $assigned_text;
}
//End function get_assigned_text 

/**
 * Function to get_available_id knowing user and post ID
 * Pulls stored value from database 
**/
function get_available_id($user_ID, $ai1ec_post_id)
{
global $wpdb;
    $table_crewmgr_assigned  = $wpdb->prefix."crewmgr_assigned";

$available_id = $wpdb->get_row("SELECT available as 'Available' FROM $table_crewmgr_assigned 
WHERE user_ID = $user_ID AND ai1ec_post_id = $ai1ec_post_id
");
$available = $available_id->Available;
// echo "user_ID: ".$user_ID."  ai1ec_post_id: ".$ai1ec_post_id."  available: ".$available."<br>"; // debug
return $available;
}
//End function get_available_id 

/**
 * Function to populate dropdown box with crew positions 
 * The position descriptions are stored in table wp_crewmgr_position
 * Important values for position include
 * position = "Not Assigned" => default
 * position = "Stay Ashore" => marks displayed row in red
 * position = "Standby Crew" => marks displayed row in yellow
 * availability = 3 => "Not Available"
 *
 * Input parameters are setup so a unique event and user, with a previously
 * stored position if it was saved.
 *
 * Output is an array variable so that the position may be identified with the
 * unique event and user for saving in the database
**/
function load_position_dropdown($post_id, $user_ID, $avail_index)
{
global $wpdb;
    $table_ai1ec_events  = $wpdb->prefix."ai1ec_events";
    $table_crewmgr_assigned  = $wpdb->prefix."crewmgr_assigned";
    $table_crewmgr_position  = $wpdb->prefix."crewmgr_position";
$query = $wpdb->get_results("SELECT cma.available 'Available', cma.id 'AvailID', cma.position_id 'Position'  FROM $table_ai1ec_events e, $table_crewmgr_assigned cma
WHERE e.post_id = $post_id AND cma.ai1ec_post_id = $post_id
AND cma.user_ID = $user_ID
", ARRAY_A);
foreach($query as $row)
{
    if ($row['AvailID']>>0){$avail_index=$row['AvailID'];} 
    ELSE {$avail_index=$post_id;}
    if ($row['Position']>>0){$position_id=$row['Position'];} 
    ELSE {$avail_index=$post_id;}
}
//End getting initial_position dropdown_value / 

$query = $wpdb->get_results("SELECT * FROM $table_crewmgr_position 
					ORDER BY position", ARRAY_A);
    $dropdown = "<select name='position[".$post_id."-".$user_ID."]' size='1' id='position[".$post_id."-".$user_ID."]'>";
    $dropdown .= "<option value='0'>-- Select a Position --</option>";
foreach($query as $myrow)
	{
    $dropdown .= "<option value=\"". $myrow["position_id"] . "\"";
	if ($myrow["position_id"]==$position_id) {
    $dropdown .= " SELECTED>";
	   $found = 1;
	   } else {
    $dropdown .= ">";
	   }
    $dropdown .= $myrow["position"]."</option>";
	}
    $dropdown .= "</select>";
return $dropdown;
}
//End function load_position_dropdown / 

/**
 * Function to populate text with crew positions 
 * Input parameters are setup so a unique event and user, with a previously
 * stored position if it was saved.
 *
 * Output is single line of text
**/
function load_position_text($post_id, $user_ID, $avail_index)
{
$current_user = wp_get_current_user(); // gets user logged in
// Get the data from the ai1ec_events table in the Wordpress database.
global $wpdb;
    $table_ai1ec_events  = $wpdb->prefix."ai1ec_events";
    $table_crewmgr_assigned  = $wpdb->prefix."crewmgr_assigned";
    $table_crewmgr_position  = $wpdb->prefix."crewmgr_position";
    $table_users  = $wpdb->prefix."users";

$query = $wpdb->get_results("SELECT cma.available 'Available', cma.id 'AvailID', cma.position_id 'Position'  FROM $table_ai1ec_events e, $table_crewmgr_assigned cma
WHERE e.post_id = $post_id AND cma.ai1ec_post_id = $post_id
AND cma.user_ID = $user_ID
", ARRAY_A);
foreach($query as $row)
{
    if ($row['AvailID']>>0){$avail_index=$row['AvailID'];} 
    ELSE {$avail_index=$post_id;}
    if ($row['Position']>>0){$position_id=$row['Position'];} 
    ELSE {$avail_index=$post_id;}
}
//End getting load_position_text / 

$crewquery = $wpdb->get_results("SELECT u.display_name 'Name', u.ID 'ID', cmp.position 'Position', cmp.position_id 'PosID', cma.available 'Available', cma.id 'AvailID', cma.assignment 'Assigned'  FROM $table_ai1ec_events e, $table_crewmgr_assigned cma, $table_crewmgr_position cmp, $table_users u  
WHERE e.post_id = $post_id AND cma.ai1ec_post_id = $post_id
AND u.ID = cma.user_ID
AND u.ID = $user_ID
AND cma.position_id = cmp.position_id
ORDER BY cma.available, u.display_name
", ARRAY_A);
	foreach($crewquery as $row)
	{
		$position_text=$row['Position'];
	}
return $position_text;
}
//End function load_position_text / 

/**
* This function gets the ai1ec post and checks for [crew] shortcode.
* If it isn't, the post content is appended with [crew]
**/
add_action( 'save_post', 'update_ai1ec_post_with_crew_shortcode' ); // trigger on post published
function update_ai1ec_post_with_crew_shortcode($post_id){
$content_post = get_post($post_id);
$post_type = $content_post -> post_type; 
	if ($post_type == 'ai1ec_event' ){ // check if this is ai1ec post
$content = $content_post -> post_content;
		if (strpos($content , '[crew]' ) !== false) { 
		} ELSE { // [crew] found
			$content .="
[crew]";
			$post = array(
			  'ID' => $post_id,
			  'post_content' => $content,
			); // array end
			global $wpdb;
		    $table_posts  = $wpdb->prefix."posts";
	        $wpdb->query("UPDATE $table_posts SET post_content='$content' WHERE ID = '$post_id' AND (post_status = 'publish' OR post_status = 'draft')");
		} // endif looking for strpos [crew]
	} // endif looking for ai1ec_event
}
// End function update_ai1ec_post_with_crew_shortcode /

// This function adds the current date to a post [date] shortcode
function displaydate(){
global $crew_manager_options; // allows global [time_offset] and 
$tz = $crew_manager_options['time_zone'];
date_default_timezone_set($tz); //Corrects for local
    return date('F jS, Y');
}
add_shortcode( 'date', 'displaydate' );
// End function to add the current date to a post


/**
 * Inserts [crew] shortcode for AI1EC Post content
 * this is commented out until I figure out how to put in ai1ec summaries
 * when looking at agenda view

function add_crew_shortcode_ai1ec($content){
  global $post;
  if( ! $post instanceof WP_Post ) return $content;

  switch( $post->post_type ) {
    case 'ai1ec_event':
      return $content.'[crew]';
    default:
      return $content;
  }
}

add_filter( 'the_content', 'add_crew_shortcode_ai1ec' );
// end of add_crew_shortcode_ai1ec ***************************
**/

/**
 * Kneller added DTG display in Upcoming Events Widget title 
 */
// This function automatically prefixes posts with the [dtg][/dtg] shortcode

// So they are displayed with the days to go in the Upcoming Event widget

// Requires /wp-content/plugins/all-in-one-event-calendar/app/view/calendar/view/abstract.php
// be modified to apply the filter 'the_title_dtg'

function show_dtg($title) {

global $wpdb;

$postid = get_the_ID(); // gets the current post ID associated with the event

$query_id = $wpdb->get_var("SELECT post_id FROM wp_ai1ec_events WHERE post_id = $postid");

	if($post_id=$query_id) {

		$title = '[dtg][/dtg]- '.$title; // this was $title

	}

	return $title;  // this was $title

}

add_filter( 'the_title_dtg', 'show_dtg' );


// This function automatically prefixes ai1ec content with the [cdt][/cdt] shortcode
// So they are displayed with the days to go when the event is opened

function show_cdt($content) {

global $wpdb;

$postid = get_the_ID(); // gets the current post ID associated with the event
    $table_ai1ec_events  = $wpdb->prefix."ai1ec_events";
$query_id = $wpdb->get_var("SELECT post_id FROM $table_ai1ec_events WHERE post_id = $postid ");

	if($post_id=$query_id) {

		$content = '<h3>[cdt][/cdt]</h3>'.$content;

	}
	return $content;
}

add_filter( 'the_content', 'show_cdt' );


/**
 * Inserts CDT shortcode for longer text "XX days until event" to use to display for AI1EC Event Posts
 * http://wpsnipp.com/index.php/functions-php/countdown-timer-shortcode-display-content-after-specified-date/
 **/

function content_countdown($atts, $content = null){

// This section gets the Unix timestamp stored for the event and converts to month, day and year

// Get the start date data from the ai1ec_events table in the Wordpress database.

global $wpdb;

$postid = get_the_ID(); // gets the current post ID associated with the event
    $table_ai1ec_events  = $wpdb->prefix."ai1ec_events";

$timestamp = $wpdb->get_var("SELECT start FROM $table_ai1ec_events WHERE post_id = $postid");
global $crew_manager_options; // allows global [time_offset] and 
$tz = $crew_manager_options['time_zone'];
date_default_timezone_set($tz); //Corrects for local

$month = date('m', $timestamp); // 1-12

$day = date('d', $timestamp); // 1-31

$year = date('Y', $timestamp); // 4 digit year

// this code lifted from code snippet but uses event date from wp table rather than numbers passed from shortcode

//  extract(shortcode_atts(array(

//     'month' => '',

//     'day'   => '',

//     'year'  => ''

//    ), $atts));
global $crew_manager_options; // allows global [time_offset] and 
$tz = $crew_manager_options['time_zone'];
date_default_timezone_set($tz); //Corrects for local
    $remain = ceil((mktime( 0,0,0,(int)$month,(int)$day,(int)$year) - time())/86400);

    if( $remain > 1 ){

        return $daysremain = "<div class=\"event\"><b>$remain</b> days until this event</div>";

    }else if($remain == 1 ){

        return $daysremain = "<div class=\"event\"><b>Tomorrow!</b></div>";

    }else{

        return $content;

    }

}

add_shortcode('cdt', 'content_countdown');

// end of CDT shortcode **********************************



/**

 * Inserts DTG shortcode for shorter text "XX days" to use to display for AI1EC Posts

 **/

function content_dtg($atts, $content = null){

// This section gets the Unix timestamp stored for the event and converts to month, day and year

// Get the start date data from the ai1ec_events table in the Wordpress database.

global $wpdb;

$postid = get_the_ID(); // gets the current post ID associated with the event
    $table_ai1ec_events  = $wpdb->prefix."ai1ec_events";

$timestamp = $wpdb->get_var("SELECT start FROM $table_ai1ec_events WHERE post_id = $postid");
global $crew_manager_options; // allows global [time_offset] and 
$tz = $crew_manager_options['time_zone'];
date_default_timezone_set($tz); //Corrects for local
$month = date('m', $timestamp); // 1-12

$day = date('d', $timestamp); // 1-31

$year = date('Y', $timestamp); // 4 digit year
    $remain = ceil((mktime( 0,0,0,(int)$month,(int)$day,(int)$year) - time())/86400);

    if( $remain > 1 ){

        return $daysremain = "in $remain days";

    }else if($remain == 1 ){

        return $daysremain = "Tomorrow! ";

    }else{

        return $content;

    }

}

add_shortcode('dtg', 'content_dtg');

// end of DTG shortcode ***************************

/**
 * Function to get email address of a user given the ID 
 * 
 * Output is single line of text
**/

function get_user_email($user_id){

  $user_info = get_userdata($user_id);
  $email_text = $user_info->user_email;
return $email_text;
}
// end of get_user_email ***************************

/**
 * Function to get the position_id given the position as text
 * 
 * Output is a number
**/

function get_position_id_number($position){
global $wpdb;
    $table_crewmgr_position  = $wpdb->prefix."crewmgr_position";

$query = $wpdb->get_results("SELECT cmp.position_id 'PositionID' FROM $table_crewmgr_position cmp
WHERE cmp.position = '$position'
", ARRAY_A);
foreach($query as $row)
{
    if ($row['PositionID']>>0)$PositionID=$row['PositionID']; 
}
return $PositionID;
}
// end of get_position_id_number ***************************


/**
 * Function creates a dropdown to get timezone
 * The timezone format is standard (e.g. America/New_York )
 * Output is dropdown with string for selected timezone
**/
function load_timezone_dropdown($saved_timezone){
/**
// this has limited time zones - replaced with global version
    $dropdown = "<select name=crew_manager_settings[time_zone] size='1' id=crew_manager_settings[time_zone]>";

//	$dropdown ="<select name=\"crew_manager_settings[time_zone]\" id=\"crew_manager_settings[time_zone]\">";
	$dropdown .="<option value=\"Pacific/Honolulu\"";
   if ($saved_timezone=="Pacific/Honolulu") $dropdown .="selected ";
	$dropdown .=">(GMT -10:00) Hawaii (US - No DST), Honolulu</option>";
	$dropdown .="<option value=\"America/Anchorage\"";
   if ($saved_timezone=="America/Anchorage") $dropdown .="selected ";
	$dropdown .="  >(GMT -9:00) Alaska (US), Anchorage</option>";
	$dropdown .="<option value=\"America/Los_Angeles\"";
   if ($saved_timezone=="America/Los_Angeles") $dropdown .="selected ";
	$dropdown .="  >(GMT -8:00) Pacific Time (US &amp; Canada), Los Angeles</option>";
	$dropdown .="<option value=\"America/Phoenix\"";
   if ($saved_timezone=="America/Phoenix") $dropdown .="selected ";
	$dropdown .="  >(GMT -7:00) Mountain Time no DST (US &amp; Canada), Phoenix</option>";
	$dropdown .="<option value=\"America/Denver\"";
   if ($saved_timezone=="America/Denver") $dropdown .="selected ";
	$dropdown .="  >(GMT -7:00) Mountain Time (US &amp; Canada), Denver</option>";
	$dropdown .="<option value=\"America/Chicago\"";
   if ($saved_timezone=="America/Chicago") $dropdown .="selected ";
	$dropdown .="  >(GMT -6:00) Central Time (US &amp; Canada), Chicago</option>";

	$dropdown .="<option value=\"America/New_York\"";
   if ($saved_timezone=="America/New_York") $dropdown .="selected ";
	$dropdown .="  >(GMT -5:00) Eastern Time (US &amp; Canada), Newport, RI</option>";

	$dropdown .="<option value=\"America/Halifax\"";
   if ($saved_timezone=="America/Halifax") $dropdown .="selected ";
 	$dropdown .="  >(GMT -4:00) Atlantic Time (Canada), Nova Scotia</option>";

	$dropdown .="<option value=\"Canada/Newfoundland\"";
   if ($saved_timezone=="Canada/Newfoundland") $dropdown .="selected ";
	$dropdown .="  >(GMT -3:30) Newfoundland Daylight Time (Canada) Newfoundland</option>";
	$dropdown .="<option value=\"Europe/London\"";
   if ($saved_timezone=="Europe/London") $dropdown .="selected ";
	$dropdown .="  >(GMT) Western Europe Time (Europe), London</option>";
	$dropdown .="<option value=\"Europe/Brussels\"";
   if ($saved_timezone=="Europe/Brussels") $dropdown .="selected ";
	$dropdown .="   >(GMT +1:00) European Time (Europe), Madrid</option>";
	$dropdown .="</select>";
**/
// this is global version of time zone selector

$regions = array(
    'Africa' => DateTimeZone::AFRICA,
    'America' => DateTimeZone::AMERICA,
    'Antarctica' => DateTimeZone::ANTARCTICA,
    'Aisa' => DateTimeZone::ASIA,
    'Atlantic' => DateTimeZone::ATLANTIC,
    'Europe' => DateTimeZone::EUROPE,
    'Indian' => DateTimeZone::INDIAN,
    'Pacific' => DateTimeZone::PACIFIC
);
$timezones = array();
foreach ($regions as $name => $mask)
{
    $zones = DateTimeZone::listIdentifiers($mask);
    foreach($zones as $timezone)
    {
		// Lets sample the time there right now
		$time = new DateTime(NULL, new DateTimeZone($timezone));
		// Us dumb Americans can't handle millitary time
		$ampm = $time->format('H') > 12 ? ' ('. $time->format('g:ia'). ')' : '';
		// Remove region name and add a sample time
		$timezones[$name][$timezone] = substr($timezone, strlen($name) + 1) . ' - ' . $time->format('H:i') . $ampm;
	} //end foreach zones
} ////end foreach regions 
// View
    $dropdown = "<select name=crew_manager_settings[time_zone] size='1' id=crew_manager_settings[time_zone]>";
foreach($timezones as $region => $list)
{
	$dropdown .='<optgroup label="' . $region . '">' . "\n";
	foreach($list as $timezone => $name)
	{
	$name = str_replace('_', ' ', $name); // make friendly name with space
//		$dropdown .='<option name="' . $timezone . '">' . $name . '</option>' . "\n";
    $selected="";
    if ($saved_timezone==$timezone) $selected=" selected "; 
    $dropdown .='<option ' . $selected . 'value="' . $timezone . '">' . $name . '</option>' . "\n";

	} //end foreach list
	$dropdown .='<optgroup>' . "\n";
} //end foreach timezones
$dropdown .='</select>';

return $dropdown;
}
// end of load_timezone_dropdown ***************************


/**
 * Function to populate text boxes with crew positions to edit
 * The position descriptions are stored in table wp_crewmgr_position
 * Important values for position_id that can not be changed include
 * position = "Not Assigned" => default
 * position = "Stay Ashore" => marks displayed row in red
 * position = "Standby Crew" => marks displayed row in yellow
 *
 * Output is an array variable so that the position may be identified, and check box to mark for deletion
**/
function load_position_text_boxes_admin()
{
global $wpdb;
    $table_crewmgr_position  = $wpdb->prefix."crewmgr_position";
$query = $wpdb->get_results("SELECT * FROM $table_crewmgr_position 
					ORDER BY position", ARRAY_A);
$dropdown="";
foreach($query as $myrow)
	{
	  if ($myrow['position']!= "Not Assigned" && $myrow['position']!=  "Stay Ashore" && $myrow['position']!= "Standby Crew" ) { 
// exclude these from editing
    $dropdown .="<br><input type='text' name='position[$myrow[position_id]]' id='position[$myrow[position_id]]' size='20' value='".$myrow['position']."'>"." Check to delete: <input type='checkbox' name='delete[$myrow[position_id]]' value='1' /> ".$myrow['position'];

	  } // endif exclude editing
	} // end foreach $query
    $dropdown .="<br><input type='text' name='newposition' id='newposition' size='20' value=''>"." <-- Type new position to be added in the text box";
return $dropdown;
}
//End function load_position_text_boxes_admin / 

/**
 * Function load_position_action_dropdown to populate position actions dropdown box
 * 0 or null = No Input
 * 1 = Edit Position Name
 * 2 = Delete Position
 * 3 = Add New Positon
**/
function load_position_action_dropdown()
{
    $dropdown = "<select name='action' size='1' id='action'>";
    $dropdown .= "<option value=0>-- Select Action --</option>";
    $dropdown .= "<option ";
    if ($action==1 ) $dropdown .= "selected ";
    $dropdown .= "value=1>Edit Position Name</option>";
    $dropdown .= "<option ";
    if ($action==2 ) $dropdown .= "selected ";
    $dropdown .= "value=2>Delete Position</option>";
    $dropdown .= "<option ";
    if ($action==3 ) $dropdown .= "selected ";
    $dropdown .= "value=3>Add New Position</option>";
    $dropdown .= "</select>";
return $dropdown;
}
//End function load_position_action_dropdown / 

/**
 * Function to populate dropdown box with multiple users for selection 
 * Input is an array with previously selected users
 * Output is an array variable so that the user data may be displayed
**/
function get_multiple_users_dropdown($input_array)
{
global $wpdb;
$query = $wpdb->get_results("SELECT u.user_login 'Logon', u.ID 'ID', u.user_email 'Email' FROM $wpdb->users as u 
ORDER BY u.user_login ", ARRAY_A);

    $dropdown = "<select name='crew[]' size='4' id='crew[]' multiple='multiple'>";
    $dropdown .= "<option value='0'>-- Select Crew --</option>";
foreach($query as $myrow)
	{
    $dropdown .= "<option value=\"". $myrow["ID"] . "\"";
    $dropdown .= ">";
    $user_info = get_userdata($myrow['ID']);
    $user_firstname = $user_info->first_name;
    $user_lastname = $user_info->last_name;
    $dropdown .= $myrow["Logon"]." -> ".$user_firstname." ".$user_lastname."</option>";
	}
    $dropdown .= "</select>";
//var_dump($query);
return $dropdown;
}
//End function get_multiple_users_dropdown / 

/**
 * Function to populate dropdown box with registered users and
 * and index name for use in Wordpress admin arrays
 * Output is an array variable so that the user data may be displayed
**/
function get_crew_dropdown($user_ID,$indexname)
{
global $wpdb;
if (!$indexname) $indexname="ID";
$query = $wpdb->get_results("SELECT u.user_login 'Logon', u.ID 'ID', u.user_email 'Email' FROM $wpdb->users as u 
ORDER BY u.user_login ", ARRAY_A);
$options = get_option( 'crew_manager_settings' );
    $dropdown = "<select name=crew_manager_settings[$indexname] size='1' id=crew_manager_settings[$indexname]>";
    $dropdown .= "<option value='0'>-- Select Crew --</option>";
foreach($query as $myrow)
	{
    $dropdown .= "<option value=\"". $myrow["ID"] . "\"";
    if ($user_ID==$myrow["ID"]) $dropdown .= " selected ";
    $dropdown .= ">";
    $user_info = get_userdata($myrow['ID']);
    $user_firstname = $user_info->first_name;
    $user_lastname = $user_info->last_name;
    $dropdown .= $myrow["Logon"]." -> ".$user_firstname." ".$user_lastname."</option>";
	}
    $dropdown .= "</select>";
//var_dump($query);
return $dropdown;
}
//End function get_crew_dropdown / 

function crew_manager_register_settings(){
	register_setting('crew_manager_group', 'crew_manager_settings');
}
//End function crew_manager_register_settings / 

add_action('admin_init', 'crew_manager_register_settings');

/**
* This loads list of all crew members into "Email posts to subscribers" plugin
* It writes the users to the table wp_elp_emaillist (no duplicates)
* in group GetNewPosts as Confirmed
**/

function load_all_crew_email($debug,$groupname){

if ($debug=="Yes") echo "<b>Debug Displays enabled with $"."debug set to \"Yes\"</b><br>";
if ($debug == "Yes") {
   echo "&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;Current Time UTC: ".$cur_datetime."  ".date('Y-m-d H:i:s',$cur_datetime)."<br>"; //debug
}
// first get the wp global and add prefix so existing data stored may be cleared
global $wpdb;
    $table_users  = $wpdb->prefix."users";
    $table_posts  = $wpdb->prefix."posts";
    $table_usermeta  = $wpdb->prefix."usermeta";
    $table_elp_emaillist  = $wpdb->prefix."elp_emaillist";
    $current_date = current_time( 'mysql' ); // uses Wordpress call

if ($debug=="Yes") echo "<b>Table</b> should be <b>wp_elp_emaillist</b>: ".$table_elp_emaillist."<br>";  // debug to make sure correct table is called
// Get all crew members 
$crewquery = $wpdb->get_results("SELECT u.ID 'ID' FROM $table_users u  
ORDER BY u.display_name
", ARRAY_A);

foreach($crewquery as $row)
{
// var_dump($row); // debug

$user_id = $row['ID'];
$user_info = $user_id ? new WP_User( $user_id ) : wp_get_current_user();
$user_name = $user_info->first_name." ".$user_info->last_name;
$user_email = $user_info->user_email;

$record_check = $wpdb->get_var("SELECT COUNT(*) FROM $table_elp_emaillist
WHERE elp_email_mail = '$user_email'
AND elp_email_group = '$groupname';"); //record is NULL if not in database so insert
    if ($record_check == 0){
// record not found so insert new record
if ($debug=="Yes") echo "Inserted -> " .$user_name . "  Email: ".$user_email." Status: Confirmed  Created: ".$current_date." Email Group: ".$groupname."<br>"; //debug
 //debug1 start comment out query

    $wpdb->insert($table_elp_emaillist, array(
        'elp_email_name' => $user_name,
        'elp_email_mail' => $user_email,
        'elp_email_status' => 'Confirmed', 
        'elp_email_created' => $current_date,
        'elp_email_viewcount' => 0,
        'elp_email_group' => $groupname
    ));

 //debug1 end
    } ELSE {
// record found so ignore it
if ($debug=="Yes") echo "-->Ignored -> " .$user_name . "  Email: ".$user_email." Created: ".$current_date."<br>"; //debug
    }
// end foreach($crewquery as $row)
} 
// end foreach($crewquery as $row)
//****** //debug turn off post status change

} // end function load_all_crew_email
?>